@@ -841,6 +841,7 @@ class MainWindow : public QMainWindow {
     bool _noteSubFolderDockWidgetVisible;
     bool _closeEventWasFired;
     ActionDialog *_actionDialog;
+    CommandBar *_commandBar;
     TodoDialog *_todoDialog;
     IssueAssistantDialog *_issueAssistantDialog;
     StoredImagesDialog *_storedImagesDialog;
@@ -1085,9 +1086,10 @@ class MainWindow : public QMainWindow {
 
     void selectAllNotesInNoteSubFolderTreeWidget() const;
 
-    bool insertAttachment(QFile *file, const QString &title = QString());
+    bool insertAttachment(QFile *file, const QString &title = QString(),
+                          const QString &fileName = QString());
 
-    bool insertTextAsAttachment(const QString &text, const QString &title = QString());
+    bool insertTextAsAttachment(const QString &text);
 
     void updatePanelsSortOrder();
 
